Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(566)

Unified Diff: Source/core/css/ElementRuleCollector.h

Issue 1033943002: Rename LayoutStyle to papayawhip (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: ensureComputedStyle Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/css/ComputedStyleCSSValueMapping.cpp ('k') | Source/core/css/ElementRuleCollector.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/css/ElementRuleCollector.h
diff --git a/Source/core/css/ElementRuleCollector.h b/Source/core/css/ElementRuleCollector.h
index d66d4516e09c5d892e60a9433b99d1bc6012b267..9670d832be32286e8db02c2154cd524922d99fca 100644
--- a/Source/core/css/ElementRuleCollector.h
+++ b/Source/core/css/ElementRuleCollector.h
@@ -101,12 +101,12 @@ public:
// ElementRuleCollector is designed to be used as a stack object.
// Create one, ask what rules the ElementResolveContext matches
// and then let it go out of scope.
// FIXME: Currently it modifies the LayoutStyle but should not!
class ElementRuleCollector {
STACK_ALLOCATED();
WTF_MAKE_NONCOPYABLE(ElementRuleCollector);
public:
- ElementRuleCollector(const ElementResolveContext&, const SelectorFilter&, LayoutStyle* = 0);
+ ElementRuleCollector(const ElementResolveContext&, const SelectorFilter&, ComputedStyle* = 0);
~ElementRuleCollector();
void setMode(SelectorChecker::Mode mode) { m_mode = mode; }
@@ -157,7 +157,7 @@ private:
private:
const ElementResolveContext& m_context;
const SelectorFilter& m_selectorFilter;
- RefPtr<LayoutStyle> m_style; // FIXME: This can be mutated during matching!
+ RefPtr<ComputedStyle> m_style; // FIXME: This can be mutated during matching!
PseudoStyleRequest m_pseudoStyleRequest;
SelectorChecker::Mode m_mode;
« no previous file with comments | « Source/core/css/ComputedStyleCSSValueMapping.cpp ('k') | Source/core/css/ElementRuleCollector.cpp » ('j') | no next file with comments »
@@ -101,12 +101,12 @@ public:
// Create one, ask what rules the ElementResolveContext matches
// and then let it go out of scope.
-// FIXME: Currently it modifies the LayoutStyle but should not!
+// FIXME: Currently it modifies the ComputedStyle but should not!
class ElementRuleCollector {
STACK_ALLOCATED();

Powered by Google App Engine
This is Rietveld 408576698